public inbox for gcc-patches@gcc.gnu.org
 help / color / mirror / Atom feed
* [PATCH] Fix PR61070
@ 2014-05-06  8:29 Richard Biener
  0 siblings, 0 replies; only message in thread
From: Richard Biener @ 2014-05-06  8:29 UTC (permalink / raw)
  To: gcc-patches


Committed as obvious.

Richard.

2014-05-06  Richard Biener  <rguenther@suse.de>

	PR middle-end/61070
	* bitmap.c (debug_bitmap): Dump to stderr, not stdout.
	* tree-ssa-structalias.c (dump_solution_for_var): Likewise.

Index: gcc/bitmap.c
===================================================================
--- gcc/bitmap.c	(revision 210097)
+++ gcc/bitmap.c	(working copy)
@@ -2117,7 +2117,7 @@ debug_bitmap_file (FILE *file, const_bit
 DEBUG_FUNCTION void
 debug_bitmap (const_bitmap head)
 {
-  debug_bitmap_file (stdout, head);
+  debug_bitmap_file (stderr, head);
 }
 
 /* Function to print out the contents of a bitmap.  Unlike debug_bitmap_file,
Index: gcc/tree-ssa-structalias.c
===================================================================
--- gcc/tree-ssa-structalias.c	(revision 210097)
+++ gcc/tree-ssa-structalias.c	(working copy)
@@ -5834,12 +5834,12 @@ dump_solution_for_var (FILE *file, unsig
   fprintf (file, "\n");
 }
 
 /* Print the points-to solution for VAR to stdout.  */
 
 DEBUG_FUNCTION void
 debug_solution_for_var (unsigned int var)
 {
-  dump_solution_for_var (stdout, var);
+  dump_solution_for_var (stderr, var);
 }
 
 /* Create varinfo structures for all of the variables in the

^ permalink raw reply	[flat|nested] only message in thread

only message in thread, other threads:[~2014-05-06  8:29 UTC | newest]

Thread overview: (only message) (download: mbox.gz / follow: Atom feed)
-- links below jump to the message on this page --
@@ -5834,12 +5834,12 @@ dump_solution_for_var (FILE *file, unsig
 }
 
-/* Print the points-to solution for VAR to stdout.  */
+/* Print the points-to solution for VAR to stderr.  */
 
 DEBUG_FUNCTION void
2014-05-06  8:29 [PATCH] Fix PR61070 Richard Biener

This is a public inbox, see mirroring instructions
for how to clone and mirror all data and code used for this inbox;
as well as URLs for read-only IMAP folder(s) and NNTP newsgroup(s).